## Changelog

Richard de Vos <rdevos72@gmail.com>
fhs_xmltv_tools
fhs-xmltv-tools

Shortlist to come:
------------------
- add mysql as sql option
- cleanup rename channels and channel descriptions

Changes
-------
- 0.1.0: initial creation
- 0.1.1: add basic search options
- 0.1.2: add join-xml-files
- 0.1.3: add run-task functionality with yaml task file
- 0.1.4: fix readme install instructions
- 0.1.5: add analyse_programs to playyaml
- 0.1.6: add execute_command tasks types and add tagging options for tags
- 0.1.7: update documentation
- 0.1.8: fix flake8 issues
- 0.1.9: tested and seems beta worthy so gone is alpha state
- 0.1.10: add sql save functions in cli and in tasks
- 0.1.11: search in sql data
- 0.1.12: cleanup sql data (older then xx days....)
- 0.1.13: add interactive mode
- 0.1.14: add rename_channel and emptyxml
- 0.1.15: add docker options
